@@ -1,10 +1,12 @@
 /*
- * SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "ldapconfigurewidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include <QLabel>
 #include <QListWidget>
 #include <QListWidgetItem>
@@ -19,11 +21,11 @@
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 
+#include "kldapcore/ldapserver.h"
 #include "ldapclientsearchconfig.h"
 #include "ldapclientsearchconfigwriteconfigjob.h"
 #include "ldapwidgetitem_p.h"
 #include "ldapwidgetitemreadconfigserverjob.h"
-#include <kldapcore/ldapserver.h>
 
 #include "addhostdialog.h"
 
@@ -107,7 +109,7 @@ void LdapConfigureWidget::slotRemoveHost()
     if (!item) {
         return;
     }
-    auto ldapItem = dynamic_cast<LdapWidgetItem *>(item);
+    auto ldapItem = static_cast<LdapWidgetItem *>(item);
     const int answer = KMessageBox::questionTwoActions(this,
                                                        i18n("Do you want to remove setting for host \"%1\"?", ldapItem->server().host()),
                                                        i18n("Remove Host"),
@@ -264,17 +266,17 @@ void LdapConfigureWidget::save()
 void LdapConfigureWidget::initGUI()
 {
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QLatin1StringView("layout"));
+    mainLayout->setObjectName("layout"_L1);
 
     // Contents of the QVGroupBox: label and hbox
-    auto label = new QLabel(i18n("Check all servers that should be used:"));
+    auto label = new QLabel(i18n("Check all servers that should be used:"), this);
     mainLayout->addWidget(label);
 
     auto hBox = new QWidget(this);
     mainLayout->addWidget(hBox);
 
     auto hBoxHBoxLayout = new QHBoxLayout(hBox);
-    hBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
+    hBoxHBoxLayout->setContentsMargins({});
     hBoxHBoxLayout->setSpacing(6);
     // Contents of the hbox: listview and up/down buttons on the right (vbox)
     mHostListView = new QListWidget(hBox);
@@ -283,7 +285,7 @@ void LdapConfigureWidget::initGUI()
 
     auto upDownBox = new QWidget(hBox);
     auto upDownBoxVBoxLayout = new QVBoxLayout(upDownBox);
-    upDownBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
+    upDownBoxVBoxLayout->setContentsMargins({});
     hBoxHBoxLayout->addWidget(upDownBox);
     upDownBoxVBoxLayout->setSpacing(6);
     mUpButton = new QToolButton(upDownBox);
